<?php
/**
 * Plugin Name: Easy Social Sharebar
 * Description: Easy sharing buttons to share any post,page etc.
 * Version: 1.0.0
 * Author: Noman Akhtar
 * Text Domain: easy-social-share
 * License: GPL v2
 */

if ( !defined( 'ABSPATH' ) ) exit;

define( 'ESS_VERSION', '1.0.0' );
define( 'ESS_NAME', 'Easy Social Sharebar' );
define( 'ESS_SLUG', 'ess' );
define( 'ESS_SETTINGS_SLUG', ESS_SLUG . '_settings' );
define( 'ESS_TEXT_DOMAIN', 'easy-social-sharing' );
define( 'ESS_ASSETS_URL', esc_url( trailingslashit( plugins_url( '/assets/', __FILE__ ) ) ) );

/**
 * Main Easy_Social_Share class
 *
 */
class Easy_Social_Sharebar
{
	private $options;

	/**
	 * Constructor
	 */
	public function __construct()
	{
		require_once plugin_dir_path( __FILE__ ) . 'includes/ESS_Options.class.php';
		$this->options = new ESS_Options( ESS_SLUG . '_' );


		// Run on plugin activation
		register_activation_hook( __FILE__, array( $this, 'ess_activation_hook' ) );

		// Run on plugin deactivation
		register_deactivation_hook( __FILE__, array( $this, 'ess_deactivation_hook' ) );

		// Register admin notice
		add_action( 'admin_notices', array( $this, 'ess_admin_notice' ) );

		// Go
		add_action( 'init', array( $this, 'ess_init' ) );

		// Register metabox
		if ( is_admin() ) {
			require_once plugin_dir_path( __FILE__ ) . 'includes/ESS_Metabox.class.php';
			new ESS_Metabox();
		}
	}

	/**
	 * Initialize the plugin.
	 *
	 * @return void
	*/
	public function ess_init()
	{
		if ( is_admin() ) {
			require_once plugin_dir_path( __FILE__ ) . 'includes/ESS_Settings.class.php';
			new ESS_Settings(__FILE__);
		} else {
			require_once plugin_dir_path( __FILE__ ) . 'includes/ESS_Frontend.class.php';
			new ESS_Frontend();
		}
	}

	/**
	 * Activation Hook - Save default
	 *
	 * @return void
	 */
	public function ess_activation_hook()
	{
		// Default options
		$defaults = array(
			'version' 				=> '1.0.0',
			'post_types' 			=> array( 'post' ),
			'buttons'				=> array( 'facebook', 'twitter', 'googleplus', 'pinterest', 'linkedin', 'whatsapp' ),
			'twitter_username'  	=> '',
			'fallback_image'		=> '',
			'buttons_order' 		=> 'facebook,twitter,googleplus,pinterest,linkedin,whatsapp',
			'buttons_placement' 	=> array( 'before' ),
			'buttons_size' 			=> 'medium',
			'buttons_color' 		=> '#',
			'buttons_hover_color' 	=> '#',
			'exclude_fontawesome' 	=> '',
			'include_social_meta' 	=> 'on',
		);

		foreach ($defaults as $name => $value) {
			$this->options->set($name, $value);
		}

		// Register transient to be used by admin_notice
		set_transient( ESS_SLUG . '_admin_notice', true, 60 * 60 );
	}

	/**
	 * Deactivation Hook - Delete options
	 *
	 * @return void
	 */
	public function ess_deactivation_hook()
	{
		$option_names = array( 'version', 'post_types', 'buttons', 'twitter_username', 'fallback_image', 'buttons_order', 'buttons_placement', 'buttons_size', 'buttons_color', 'buttons_hover_color', 'exclude_fontawesome', 'include_social_meta' );

		foreach ( $option_names as $option_name ) {
			$this->options->remove( $option_name );
		}
	}

	function ess_admin_notice() {
		if ( !get_transient( ESS_SLUG . '_admin_notice' ) )
			return;

		if ( get_current_screen()->base == 'settings_page_' . ESS_SLUG . '-settings' ){
			delete_transient( ESS_SLUG . '_admin_notice' );
			return;
		}
		?>
	    <div class="notice notice-success is-dismissible">
	        <p><?php _e( 'Thank you for using Easy Social Sharing. Adjust the <a href="' . admin_url( 'options-general.php?page=' . ESS_SLUG . '-settings', 'admin' ) . '">plugin settings</a> to get the most out of it.', ESS_TEXT_DOMAIN ); ?></p>
	    </div>
	    <?php
	}
}

new Easy_Social_Sharebar;