<?php

/**
 * Responsible for frontend control
 */
Class ESS_Frontend
{
	private $options,
			$buttons_properties,
			$meta_name,
			$color,
			$hover_color;

	/**
     * Constructor
     */
	public function __construct()
	{
		$this->options = new ESS_Options( ESS_SLUG . '_' );
		$this->buttons_properties = array(
			'facebook' => array(
				'icon'  => 'facebook',
				'label' => 'Share'
			),
			'twitter' => array(
				'icon'  => 'twitter',
				'label' => 'Tweet'
			),
			'googleplus' => array(
				'icon'  => 'google-plus',
				'label' => 'Share'
			),
			'pinterest' => array(
				'icon'  => 'pinterest-p',
				'label' => 'Pint it'
			),
			'linkedin' => array(
				'icon'  => 'linkedin',
				'label' => 'Share'
			),
			'whatsapp' => array(
				'icon'  => 'whatsapp',
				'label' => 'Share'
			),
		);
		$this->meta_name = ESS_SLUG . '_display_buttons';

		add_action('wp_head', array($this, 'ess_print_social_meta_tags') );

		add_filter('the_content', array( $this, 'ess_render_buttons') );
		add_filter('the_excerpt', array($this, 'ess_render_buttons'));
		add_filter('get_the_content', array( $this, 'ess_render_buttons') );
		add_filter( 'post_thumbnail_html', array( $this, 'ess_render_buttons_featured_image' ), 10, 1 );

		// Register two shortcodes for the sake of clarity
		add_shortcode('ess', array( $this, 'ess_shortcode' ) );
		add_shortcode('easy_social_sharing', array( $this, 'ess_shortcode' ) );
	}

	/**
	 * Prints social meta tags to wp_head
	 */
	public function ess_print_social_meta_tags() {
		$thumbnail = get_the_post_thumbnail_url( 'medium' );
		if ( !$thumbnail ) {
			$thumbnail = wp_get_attachment_url( $this->options->get( 'fallback_image' ) );
		}

		$twitter_username = $this->options->get( 'twitter_username' );
		?>
		<!-- Schema.org markup for Google+ -->
		<meta itemprop="name" content="<?php the_title(); ?>">
		<meta itemprop="description" content="<?php echo get_the_excerpt(); ?>">
		<meta itemprop="image" content="<?php echo $thumbnail; ?>">

		<!-- Twitter Card data -->
		<meta name="twitter:card" content="summary_large_image">
		<?php if ( !empty( $twitter_username ) ) : ?>
		<meta name="twitter:site" content="<?php echo '@' . $twitter_username; ?>">
		<?php endif; ?>
		<meta name="twitter:title" content="<?php the_title(); ?>">
		<meta name="twitter:description" content="<?php get_the_excerpt(); ?>">
		<!-- Twitter summary card with large image must be at least 280x150px -->
		<meta name="twitter:image:src" content="<?php $thumbnail; ?>">

		<!-- Open Graph data -->
		<meta property="og:title" content="<?php the_title(); ?>" />
		<meta property="og:type" content="article" />
		<meta property="og:url" content="<?php the_permalink(); ?>" />
		<meta property="og:image" content="<?php echo $thumbnail; ?>" />
		<meta property="og:description" content="<?php echo get_the_excerpt(); ?>" />
		<meta property="og:site_name" content="<?php bloginfo( 'name' ); ?>" />
		<?php
	}

	/**
	 * Renders ESS buttons
	 *
	 * @return HTML
	 */
	public function ess_render_buttons( $content )
	{
		if ( !$this->is_ess_page_eligible() ) {
			return $content;
		}

		$buttons_placement = $this->options->get( 'buttons_placement', array() );
		$buttons = do_shortcode( '[ess order="settings" placement=""]' );

		foreach ( $buttons_placement as $placement ) {
			if ( $placement == 'featured_image' )
				continue;

			$buttons_final = str_replace( '{{placement}}', $placement, $buttons );

			switch ( $placement ) {
				case 'before':
				case 'float':
					$content = $buttons_final . $content;
					break;

				case 'after':
					$content .= $buttons_final;
					break;
			}
		}

		return $content;
	}

	/**
	 * Shortcode for Easy Social Sharing
	 *
	 * @param  array $atts User define shortcode attribute values
	 * @return HTML        Rendered social shring buttons
	 */
	public function ess_shortcode ( $atts )
	{
		/* if ( !is_singular() ) {
			return;
		}
		*/

		extract( shortcode_atts( array(
			'buttons'		=> $this->options->get( 'buttons', array() ),
			'order' 	 	=> '',
			'size' 		 	=> $this->options->get( 'buttons_size' ),
			'color' 	 	=> $this->options->get( 'buttons_color' ),
			'hover_color' 	=> $this->options->get( 'buttons_hover_color' ),
			'placement' 	=> 'shortcode',
		), $atts ) );

		$this->color = $color;
		$this->hover_color = $hover_color;

		add_action( 'wp_footer', function(){
			echo '<link rel="stylesheet" href="' . ESS_ASSETS_URL . 'css/frontend.css" type="text/css" media="all" />';

			if ( $this->options->get( 'exclude_fontawesome', 'off' ) != 'on' ) {
				echo '<link rel="stylesheet" href="' . ESS_ASSETS_URL . 'css/font-awesome.min.css" type="text/css" media="all" />';
			}

			if ( $this->color != '#' ) {
			?>
				<style type="text/css">
					.ess-buttons .ess-button {
					    background-color: <?php echo $this->color; ?>;
					}
				</style>
			<?php
			}

			if ( $this->hover_color != '#' ) {
			?>
				<style type="text/css">
					.ess-buttons .ess-button:hover {
					    background-color: <?php echo $this->hover_color; ?>;
					}
				</style>
			<?php
			}

			?>
			<script type="text/javascript">
				if ( !/android|webos|iphone|ipad|ipod|blackberry|iemobile|opera mini/i.test( navigator.userAgent.toLowerCase() ) ) {
					jQuery('.ess-button-whatsapp').hide();
				}

				jQuery('.ess-container').fadeIn();
			</script>
			<?php
		} );

		$networks = $buttons;

		if ( $networks == 'all' ) {
			$networks = array( 'facebook', 'twitter', 'googleplus', 'pinterest', 'linkedin', 'whatsapp' );
		} elseif ( !is_array( $networks ) ) {
			$networks = array_filter( array_map( 'trim', explode( ',', $networks ) ) );
		}

		// order="settings" is only expected to be passed from the_content filter.
		// If so, that means we need to use order defined in settings
		if ( $order == 'settings' ) {
			$order = explode( ',', $this->options->get( 'buttons_order' ) );
		} else {
			$order = $networks;
		}

		$output = '';

		remove_filter('the_title','wptexturize');
		$title = html_entity_decode( get_the_title() );
		add_filter('the_title','wptexturize');

		$permalink = get_permalink();
		$thumbnail = get_the_post_thumbnail_url( get_the_ID(), 'medium' );

		if ( !$thumbnail ) {
			$thumbnail = wp_get_attachment_url( $this->options->get( 'fallback_image' ) );
		}

		ob_start();
		?>
		<div class="ess-container ess-placement-<?php echo ( in_array( $placement, ['shortcode', 'featured'] ) ) ? $placement : '{{placement}}'; ?>">
		 <div class="ess-buttons">
		 	<?php foreach( $order as $network ) : ?>
		 		<?php if ( in_array( $network, $networks ) ) : ?>
			    <a class="ess-button ess-button-<?php echo $network ?> ess-button-<?php echo $this->options->get( 'buttons_size', 'medium' ); ?>" href="<?php echo $this->ess_get_shareable_url( $network, $permalink, $title, $thumbnail ); ?>"" rel="nofollow" target="_blank">
			       <i class="fa fa-<?php echo $this->buttons_properties[$network]['icon']; ?>" aria-hidden="true"></i><?php echo $this->buttons_properties[$network]['label']; ?>
			    </a>
				<?php endif; ?>
			<?php endforeach; ?>
		 </div>
		 <div style="clear: both;"></div>
		</div>
		<?php
		$output .= ob_get_clean();

		return $output;
	}

	/**
	 * Renders the buttons and returns to 'post_thumbnail_html' filter
	 * @param  string $html Post thumbnail HTML
	 * @return string       Post thumbnail + buttons
	 */
	public function ess_render_buttons_featured_image( $html )
	{
		if ( !$this->is_ess_page_eligible() || !in_array( 'featured_image', $this->options->get( 'buttons_placement', array() ) ) ) {
			return $html;
		}

	  return $html . do_shortcode( '[ess order="settings" placement="featured"]' );
	}

	/**
	 * Creates a valid shareable url
	 *
	 * @param  string $network Network name
	 * @param  string $permalink Current page url
	 * @param  string $title Current page title
	 * @return string          Shareable URL
	 */
	private function ess_get_shareable_url( $network, $permalink, $title, $thumbnail )
	{
		$url = '#';

		switch ( $network ) {
			case 'facebook':
				$url = 'https://www.facebook.com/sharer/sharer.php?u=' . $permalink;
				break;

			case 'twitter':
				$twitter_username = $this->options->get( 'twitter_username', '' );
				$url = 'http://twitter.com/intent/tweet/?text=' . $title . '&url=' . $permalink;
				if (  !empty( $twitter_username ) ) {
					$url .= '&via=' . $twitter_username;
				}
				break;

			case 'googleplus':
				$url = 'https://plus.google.com/share?url=' . $permalink;
				break;

			case 'pinterest':
				$url = 'http://pinterest.com/pin/create/button/?url=' . $permalink . '&media=' . $thumbnail . '&description=' . $title;
				break;

			case 'linkedin':
				$url = 'http://www.linkedin.com/shareArticle?mini=true&url=' . substr( $permalink, 0, 1024) . '&title=' . substr( $title, 0, 200);
				break;

			case 'whatsapp':
				$url = 'whatsapp://send?text=' . $title . '%0A%0A' . $permalink;
				break;
		}

		return $url;
	}

	/**
	 * Checks if current page is eligible to dispaly ESS buttons
	 * Logic is based on the settign "Post Types"
	 *
	 * @return boolean
	 */
	private function is_ess_page_eligible()
	{
		if ( !is_singular() ) {
			return in_array( get_post_meta( get_the_ID(), $this->meta_name, true ), ['on', ''] );
		}
		else{
		 return is_singular( $this->options->get( 'post_types', array() ) ) && in_array( get_post_meta( get_the_ID(), $this->meta_name, true ), ['on', ''] );
		}
	}
}