<?php

/**
 * Responsible for handling metabox on edit page
 */
class ESS_Metabox
{

	private $meta_name,
			$nonce_name;

	/**
	 * Constructor
	 */
	public function __construct()
	{
		$this->meta_name = ESS_SLUG . '_display_buttons';
		$this->nonce_name = ESS_SLUG . '_display_nonce';

		add_action( 'add_meta_boxes', array( $this, 'ess_add_meta_box' ) );
		add_action( 'save_post',      array( $this, 'ess_save_meta_box' ) );
	}

	/**
     * Adds the meta box container
     */
	public function ess_add_meta_box()
	{
		add_meta_box(
			ESS_SLUG . '-metabox',
			'Easy Social Sharing',
			array( $this, 'ess_render_meta_box_content' ),
			null,
			'side',
			'high'
		);
	}

	/**
     * Save the meta when the post is saved.
     *
     * @param int $post_id The ID of the post being saved.
     */
    public function ess_save_meta_box( $post_id )
    {

        // Check if our nonce is set.
        if ( ! isset( $_POST[ $this->nonce_name ] ) ) {
            return $post_id;
        }

        $nonce = $_POST[ $this->nonce_name ];

        // Verify that the nonce is valid.
        if ( ! wp_verify_nonce( $nonce, $this->nonce_name ) ) {
            return $post_id;
        }

        /*
         * If this is an autosave, our form has not been submitted,
         * so we don't want to do anything.
         */
        if ( defined( 'DOING_AUTOSAVE' ) && DOING_AUTOSAVE ) {
            return $post_id;
        }

        // Check the user's permissions.
        if ( 'page' == $_POST['post_type'] ) {
            if ( ! current_user_can( 'edit_page', $post_id ) ) {
                return $post_id;
            }
        } else {
            if ( ! current_user_can( 'edit_post', $post_id ) ) {
                return $post_id;
            }
        }

        /* OK, it's safe for us to save the data now. */

        // Sanitize the user input.
        $ess_display_buttons = sanitize_text_field( $_POST[ $this->meta_name ] );
        $value = 'on';

        if ( $ess_display_buttons != 'on' ) {
        	$value = 'off';
        }

        // Update the meta field.
        update_post_meta( $post_id, $this->meta_name, $value );
    }

	/**
     * Render Meta Box content.
     *
     * @param WP_Post $post The post object.
     */
	public function ess_render_meta_box_content( $post )
	{
		// Add an nonce field so we can check for it later.
        wp_nonce_field( $this->nonce_name, $this->nonce_name );

        // Use get_post_meta to retrieve an existing value from the database.
        $value = get_post_meta( $post->ID, $this->meta_name, true );

        $checked = false;
        if( empty( $value ) || $value == 'on' ){
			$checked = true;
		}

        // Display the form, using the current value.
        ?>
        <label for="<?php echo $this->meta_name; ?>">
        	<input id="<?php echo $this->meta_name; ?>" type="checkbox" name="<?php echo $this->meta_name; ?>" <?php checked( $checked, true, true ); ?>/>
            <?php _e( 'Include automatic social buttons', ESS_TEXT_DOMAIN ); ?>
        </label>
        <br>
        <br>
        <span>This option has no effect on shortcode output.</span>
        <?php
	}
}