<?php

/**
 * Manages options for Easy Social Sharing using the options API.
 */
class ESS_Options
{

    /**
     * The prefix used by all option names.
     *
     * @var string
     */
    private $prefix;

    /**
     * Constructor.
     *
     * @param string $prefix
     */
    public function __construct( $prefix = '' )
    {
        $this->prefix = $prefix;
    }

    /**
     * Gets option for the given name.
     *
     * @param string $name
     * @param mixed  $default
     *
     * @return mixed
     */
    public function get( $name, $default = null )
    {
        $option = get_option( $this->get_option_name( $name ), $default );

        if ( is_array( $default ) && !is_array( $option ) ) {
            $option = (array) $option;
        }

        return $option;
    }

    /**
     * Removes the option with the given name.
     *
     * @param string $name
     */
    public function remove( $name )
    {
        delete_option( $this->get_option_name( $name ) );
    }

    /**
     * Sets an option. Overwrites the existing option if the name is already in use.
     *
     * @param string $name
     * @param mixed  $value
     */
    public function set( $name, $value )
    {
        update_option( $this->get_option_name( $name ), $value );
    }

    /**
     * Get the option name used to store the option in the WordPress database.
     *
     * @param string $name
     *
     * @return string
     */
    public function get_option_name( $name )
    {
        return $this->prefix . $name;
    }
}